@@ -55,6 +55,7 @@ def hostname(
     skip_ipv4_addr: bool = False,
     may_have_port: bool = True,
     maybe_simple: bool = True,
+    consider_tld: bool = False,
     private: Optional[bool] = None,  # only for ip-addresses
     rfc_1034: bool = False,
     rfc_2782: bool = False,
@@ -94,6 +95,8 @@ def hostname(
             Hostname string may contain port number.
         maybe_simple:
             Hostname string maybe only hyphens and alpha-numerals.
+        consider_tld:
+            Restrict domain to TLDs allowed by IANA.
         private:
             Embedded IP address is public if `False`, private/local if `True`.
         rfc_1034:
@@ -113,14 +116,14 @@ def hostname(
     if may_have_port and (host_seg := _port_validator(value)):
         return (
             (_simple_hostname_regex().match(host_seg) if maybe_simple else False)
-            or domain(host_seg, rfc_1034=rfc_1034, rfc_2782=rfc_2782)
+            or domain(host_seg, consider_tld=consider_tld, rfc_1034=rfc_1034, rfc_2782=rfc_2782)
             or (False if skip_ipv4_addr else ipv4(host_seg, cidr=False, private=private))
             or (False if skip_ipv6_addr else ipv6(host_seg, cidr=False))
         )
 
     return (
         (_simple_hostname_regex().match(value) if maybe_simple else False)
-        or domain(value, rfc_1034=rfc_1034, rfc_2782=rfc_2782)
+        or domain(value, consider_tld=consider_tld, rfc_1034=rfc_1034, rfc_2782=rfc_2782)
         or (False if skip_ipv4_addr else ipv4(value, cidr=False, private=private))
         or (False if skip_ipv6_addr else ipv6(value, cidr=False))
     )
