@@ -1,5 +1,4 @@
 """MAC Address."""
-# -*- coding: utf-8 -*-
 
 # standard
 import re
@@ -20,18 +19,14 @@ def mac_address(value: str, /):
         >>> mac_address('01:23:45:67:ab:CD')
         # Output: True
         >>> mac_address('00:00:00:00:00')
-        # Output: ValidationFailure(func=mac_address, args={'value': '00:00:00:00:00'})
+        # Output: ValidationError(func=mac_address, args={'value': '00:00:00:00:00'})
 
     Args:
         value:
             MAC address string to validate.
 
     Returns:
-        (Literal[True]):
-            If `value` is a valid MAC address.
-        (ValidationFailure):
-            If `value` is an invalid MAC address.
-
-    > *New in version 0.2.0*.
+        (Literal[True]): If `value` is a valid MAC address.
+        (ValidationError): If `value` is an invalid MAC address.
     """
-    return re.match(r"^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$", value)
+    return re.match(r"^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$", value) if value else False
